Enum SubtractionError

enum SubtractionError

Errors that can occur when subtracting another histogram.

Variants

SubtrahendValueExceedsMinuendRange

The other histogram includes values that do not fit in this histogram's range. Only possible when auto resize is disabled.

SubtrahendCountExceedsMinuendCount

The other histogram includes counts that are higher than the current count for a value, and counts cannot go negative. The subtraction may have been partially applied to some counts as this error is returned when the first impossible subtraction is detected.

Implementations

impl Clone for SubtractionError

fn clone(self: &Self) -> SubtractionError

impl Copy for SubtractionError

impl Debug for SubtractionError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for SubtractionError

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for SubtractionError

impl Error for SubtractionError

impl Freeze for SubtractionError

impl PartialEq for SubtractionError

fn eq(self: &Self, other: &SubtractionError) -> bool

impl RefUnwindSafe for SubtractionError

impl Send for SubtractionError

impl StructuralPartialEq for SubtractionError

impl Sync for SubtractionError

impl Unpin for SubtractionError

impl UnsafeUnpin for SubtractionError

impl UnwindSafe for SubtractionError

impl<T> Any for SubtractionError

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SubtractionError

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SubtractionError

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SubtractionError

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SubtractionError

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SubtractionError

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for SubtractionError

fn to_string(self: &Self) -> String

impl<T, U> Into for SubtractionError

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SubtractionError

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SubtractionError

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>