Struct Iter

struct Iter { ... }

An iterator that will yield only bins with at least one sample.

Implementations

impl Iter

fn new<T: Counter>(hist: &Histogram<T>) -> HistogramIterator<'_, T, Iter>

Construct a new sampled iterator. See Histogram::iter_recorded for details.

impl Freeze for Iter

impl RefUnwindSafe for Iter

impl Send for Iter

impl Sync for Iter

impl Unpin for Iter

impl UnsafeUnpin for Iter

impl UnwindSafe for Iter

impl<T> Any for Iter

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Iter

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Iter

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Iter

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Iter

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Iter

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Iter

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: Counter> PickyIterator for Iter

fn pick(self: &mut Self, index: usize, _: u64, count_at_index: T) -> Option<PickMetadata>
fn more(self: &mut Self, _: usize) -> bool