Struct HistogramIterator
struct HistogramIterator<'a, T: 'a + Counter, P: PickyIterator<T>> { ... }
HistogramIterator provides a base iterator for a Histogram.
It will iterate over all discrete values until there are no more recorded values (i.e., not necessarily until all bins have been exhausted). To facilitate the development of more sophisticated iterators, a picker is also provided, which is allowed to only select some bins that should be yielded. The picker may also extend the iteration to include a suffix of empty bins.
Implementations
impl<'a, T, P> Freeze for HistogramIterator<'a, T, P>
impl<'a, T, P> Iterator for HistogramIterator<'a, T, P>
fn next(self: &mut Self) -> Option<<Self as >::Item>
impl<'a, T, P> RefUnwindSafe for HistogramIterator<'a, T, P>
impl<'a, T, P> Send for HistogramIterator<'a, T, P>
impl<'a, T, P> Sync for HistogramIterator<'a, T, P>
impl<'a, T, P> Unpin for HistogramIterator<'a, T, P>
impl<'a, T, P> UnsafeUnpin for HistogramIterator<'a, T, P>
impl<'a, T, P> UnwindSafe for HistogramIterator<'a, T, P>
impl<I> IntoIterator for HistogramIterator<'a, T, P>
fn into_iter(self: Self) -> I
impl<T> Any for HistogramIterator<'a, T, P>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for HistogramIterator<'a, T, P>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for HistogramIterator<'a, T, P>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for HistogramIterator<'a, T, P>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for HistogramIterator<'a, T, P>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for HistogramIterator<'a, T, P>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for HistogramIterator<'a, T, P>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>