Struct IterationValue
struct IterationValue<T: Counter> { ... }
The value emitted at each step when iterating over a Histogram.
Implementations
impl<T: Counter> IterationValue<T>
fn new(value_iterated_to: u64, quantile: f64, quantile_iterated_to: f64, count_at_value: T, count_since_last_iteration: u64) -> IterationValue<T>Create a new IterationValue.
fn value_iterated_to(self: &Self) -> u64The value iterated to. Some iterators provide a specific value inside the bucket, while others just use the highest value in the bucket.
fn percentile(self: &Self) -> f64Percent of recorded values that are at or below the current bucket. This is simply the quantile multiplied by 100.0, so if you care about maintaining the best floating-point precision, use
quantile()instead.fn quantile(self: &Self) -> f64Quantile of recorded values that are at or below the current bucket.
fn quantile_iterated_to(self: &Self) -> f64Quantile iterated to, which may be different than
quantile()when an iterator provides information about the specific quantile it's iterating to.fn count_at_value(self: &Self) -> TRecorded count for values equivalent to
valuefn count_since_last_iteration(self: &Self) -> u64Number of values traversed since the last iteration step
impl<T> Any for IterationValue<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for IterationValue<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for IterationValue<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Freeze for IterationValue<T>
impl<T> From for IterationValue<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> RefUnwindSafe for IterationValue<T>
impl<T> Send for IterationValue<T>
impl<T> Sync for IterationValue<T>
impl<T> Unpin for IterationValue<T>
impl<T> UnsafeUnpin for IterationValue<T>
impl<T> UnwindSafe for IterationValue<T>
impl<T, U> Into for IterationValue<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for IterationValue<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for IterationValue<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::cmp::PartialEq + Counter> PartialEq for IterationValue<T>
fn eq(self: &Self, other: &IterationValue<T>) -> bool
impl<T: $crate::fmt::Debug + Counter> Debug for IterationValue<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result