Struct PickMetadata

struct PickMetadata { ... }

Extra information about the picked point in the histogram provided by the picker.

Implementations

impl Freeze for PickMetadata

impl RefUnwindSafe for PickMetadata

impl Send for PickMetadata

impl Sync for PickMetadata

impl Unpin for PickMetadata

impl UnsafeUnpin for PickMetadata

impl UnwindSafe for PickMetadata

impl<T> Any for PickMetadata

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PickMetadata

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PickMetadata

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for PickMetadata

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for PickMetadata

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PickMetadata

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PickMetadata

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>